@@ -3,7 +3,6 @@ from starlette.datastructures import Headers
 from Osdental.Models.Response import Response
 from Osdental.Models.FakeInfo import FakeInfo
 from Osdental.Shared.Enums.GrahpqlOperation import GraphqlOperation
-from Osdental.Shared.Enums.Constant import Constant
 
 # Client
 def with_grpc_metadata(func):
@@ -31,8 +30,7 @@ def with_grpc_metadata(func):
         res = await func(self, request, metadata, *args, **kwargs)
 
         # Return a uniform Response
-        decoded = res.data.decode(Constant.DEFAULT_ENCODING) if res.data else None
-        return Response(status=res.status, message=res.message, data=decoded)
+        return Response(status=res.status, message=res.message, data=res.data)
 
     return wrapper
 
