@@ -17,4 +17,7 @@ class Code(StrEnum):
     REQUEST_VALIDATION_ERROR_CODE = 'DB_WARNING_REQUEST_VALIDATION'
     MISSING_FIELD_ERROR_CODE = 'DB_WARNING_MISSING_FIELD'
     PROFILE_PERMISSION_DENIED_CODE = 'DB_WARNING_PROFILE_PERMISSION_DENIED'
-    INVALID_FORMAT_CODE = 'DB_WARNING_INVALID_FORMAT'
\ No newline at end of file
+    INVALID_FORMAT_CODE = 'DB_WARNING_INVALID_FORMAT'
+    INTEGRITY_DB_ERROR_CODE = 'DB_WARNING_INTEGRITY_DB'
+    OPERATIONAL_DB_ERROR_CODE = 'DB_WARNING_OPERATIONAL_DB'
+    DB_UNKNOWN_ERROR_CODE = 'DB_WARNING_UNKNOWN'
